@@ -18,28 +18,25 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
-from gi.repository import Gst
-import gi
-from common import TestCase, unittest
 import overrides_hack
 overrides_hack
 
+from common import TestCase, unittest
 
+import gi
 gi.require_version("Gst", "1.0")
+from gi.repository import Gst
 
 
 class TestPlugin(TestCase):
     def testLoad(self):
         Gst.init(None)
-        p = Gst.parse_launch("fakesrc ! test_identity_py name=id ! fakesink")
-        assert p.get_by_name("id").transformed is False
+        p = Gst.parse_launch ("fakesrc ! test_identity_py name=id ! fakesink")
+        assert p.get_by_name("id").transformed == False
         p.set_state(Gst.State.PLAYING)
         p.get_state(Gst.CLOCK_TIME_NONE)
         p.set_state(Gst.State.NULL)
-        assert p.get_by_name("id").transformed is True
-
-        del p
-
+        assert p.get_by_name("id").transformed == True
 
 if __name__ == "__main__":
     unittest.main()
